#ifndef _EFL_UI_TAB_BAR_EO_H_
#define _EFL_UI_TAB_BAR_EO_H_

#ifndef _EFL_UI_TAB_BAR_EO_CLASS_TYPE
#define _EFL_UI_TAB_BAR_EO_CLASS_TYPE

typedef Eo Efl_Ui_Tab_Bar;

#endif

#ifndef _EFL_UI_TAB_BAR_EO_TYPES
#define _EFL_UI_TAB_BAR_EO_TYPES


#endif
/** Tab Bar class
 *
 * @ingroup Efl_Ui_Tab_Bar
 */
#define EFL_UI_TAB_BAR_CLASS efl_ui_tab_bar_class_get()

EWAPI const Efl_Class *efl_ui_tab_bar_class_get(void);

EOAPI void efl_ui_tab_bar_current_tab_set(Eo *obj, int index);

EOAPI int efl_ui_tab_bar_current_tab_get(const Eo *obj);

EOAPI unsigned int efl_ui_tab_bar_tab_count(const Eo *obj);

#ifdef EFL_UI_TAB_BAR_BETA
EOAPI void efl_ui_tab_bar_tab_add(Eo *obj, int index, const char *label, const char *icon);
#endif

#ifdef EFL_UI_TAB_BAR_BETA
EOAPI void efl_ui_tab_bar_tab_remove(Eo *obj, int index);
#endif

#ifdef EFL_UI_TAB_BAR_BETA
EOAPI void efl_ui_tab_bar_tab_label_set(Eo *obj, int index, const char *label);
#endif

#ifdef EFL_UI_TAB_BAR_BETA
EOAPI void efl_ui_tab_bar_tab_icon_set(Eo *obj, int index, const char *icon);
#endif

#endif
